diff src/insexpand.c @ 19199:8cbadf7fb9d4 v8.2.0158

patch 8.2.0158: triggering CompleteDone earlier is not backwards compatible Commit: https://github.com/vim/vim/commit/3f169ce17e8b779d105c96138a8b4246f2d270b9 Author: Bram Moolenaar <Bram@vim.org> Date: Sun Jan 26 22:43:31 2020 +0100 patch 8.2.0158: triggering CompleteDone earlier is not backwards compatible Problem: Triggering CompleteDone earlier is not backwards compatible. (Daniel Hahler) Solution: Add CompleteDonePre instead.
author Bram Moolenaar <Bram@vim.org>
date Sun, 26 Jan 2020 22:45:03 +0100
parents 1f67e58e7f8c
children e7b4fff348dd
line wrap: on
line diff
--- a/src/insexpand.c
+++ b/src/insexpand.c
@@ -2061,12 +2061,11 @@ ins_compl_prep(int c)
 
 	    auto_format(FALSE, TRUE);
 
 	    // Trigger the CompleteDone event to give scripts a chance to
 	    // act upon the completion.  Do this before clearing the info,
 	    // and restore ctrl_x_mode, so that complete_info() can be
 	    // used.
 	    ctrl_x_mode = prev_mode;
-	    ins_apply_autocmds(EVENT_COMPLETEDONE);
+	    ins_apply_autocmds(EVENT_COMPLETEDONEPRE);
 
 	    ins_compl_free();
 	    compl_started = FALSE;
@@ -2092,6 +2091,9 @@ ins_compl_prep(int c)
 	    if (want_cindent && in_cinkeys(KEY_COMPLETE, ' ', inindent(0)))
 		do_c_expr_indent();
 #endif
+	    // Trigger the CompleteDone event to give scripts a chance to act
+	    // upon the end of completion.
+	    ins_apply_autocmds(EVENT_COMPLETEDONE);
 	}
     }
     else if (ctrl_x_mode == CTRL_X_LOCAL_MSG)
@@ -2061,12 +2061,11 @@ ins_compl_prep(int c)
 	    auto_format(FALSE, TRUE);
 
-	    // Trigger the CompleteDone event to give scripts a chance to
-	    // act upon the completion.  Do this before clearing the info,
-	    // and restore ctrl_x_mode, so that complete_info() can be
-	    // used.
+	    // Trigger the CompleteDonePre event to give scripts a chance to
+	    // act upon the completion before clearing the info, and restore
+	    // ctrl_x_mode, so that complete_info() can be used.
 	    ctrl_x_mode = prev_mode;